CellularAutomaton<Coordinate, Base> class

A cellular automaton.

Constructors

CellularAutomaton({required Map<Coordinate, Base> state, required List<Rule<Coordinate, Base>> rules})
A cellular automaton.

Properties

hashCode int
The hash code for this object.
no setterinherited
locked bool
Whether the automaton is locked.
no setter
rules UnmodifiableListView<Rule<Coordinate, Base>>
Rules that define the behavior of the automaton.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state UnmodifiableMapView<Coordinate, Base>
A map of reflecting the state of the two-dimensional cellular automaton.
no setter

Methods

alter({Map<Coordinate, Base>? state, List<Rule<Coordinate, Base>>? rules}) → void
Creates a copy of the automaton with the given parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
step() FutureOr<void>
Steps the generation forward by one.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited