LockedStateException class

Exception thrown when a CellularAutomaton is stepped or altered while locked.

A CellularAutomaton is locked when it is altering its internal configuration. For example, stepping into a new state or updating its rules.

Implemented types

Constructors

LockedStateException()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited