Rule<Coordinate, Base> class abstract

A rule matches a cell to its next state according to its neighbourhood.

Constructors

Rule()
A rule matches a cell to its next state according to its neighbourhood.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(UnmodifiableMapView<Coordinate, Base> neighbourhood, Coordinate coordinate) FutureOr<Base>
Applies the rule to the neighbourhood and returns the new state of the cell at coordinate.
matches(UnmodifiableMapView<Coordinate, Base> neighbourhood, Coordinate coordinate) bool
Whether the rule matches against the neighbourhood.
neighbourhood(UnmodifiableMapView<Coordinate, Base> state, Coordinate coordinate) Map<Coordinate, Base>
Reduces the state to the visible neighborhood of coordinate.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited