Rule<Coordinate, Base> constructor
const
Rule<Coordinate, Base> ()
A rule matches a cell to its next state according to its neighbourhood.
Implementation
const Rule();
A rule matches a cell to its next state according to its neighbourhood.
const Rule();