apply abstract method
Applies the rule to the neighbourhood and returns the new state of the
cell at coordinate.
Implementation
FutureOr<Base> apply(
UnmodifiableMapView<Coordinate, Base> neighbourhood,
Coordinate coordinate,
);
Applies the rule to the neighbourhood and returns the new state of the
cell at coordinate.
FutureOr<Base> apply(
UnmodifiableMapView<Coordinate, Base> neighbourhood,
Coordinate coordinate,
);