yaca library
Classes
-
CellularAutomaton<
Coordinate, Base> - A cellular automaton.
-
Rule<
Coordinate, Base> - A rule matches a cell to its next state according to its neighbourhood.
Exceptions / Errors
- CellularAutomatonException
- Exception thrown by CellularAutomaton.
- LockedStateException
- Exception thrown when a CellularAutomaton is stepped or altered while locked.
- UndefinedStateException
- Exception thrown when a CellularAutomaton is stepped without a rule matching the current state.